@@ -1,4 +1,5 @@
 import datetime
+from pathlib import Path
 
 import requests
 
@@ -7,6 +8,12 @@ from .. import config
 
 
 def initialize_node2vec():
+    LIB_DIR = Path(__file__).resolve().parent / 'lib'
+
+    if not LIB_DIR.exists():
+        print('libs_dir: creating')
+        safe_create_dir(LIB_DIR)
+
     print('node2vec: checking')
     # load node2vec as python 3 module
     node2_vec_name = 'node2vec.py'
@@ -28,8 +35,4 @@ def initialize_node2vec():
         print('node2vec: already exists skipping')
 
 
-if not config.LIB_DIR.exists():
-    print('libs_dir: creating')
-    safe_create_dir(config.LIB_DIR)
-
 initialize_node2vec()
